==> org.eclipse.incquery.uml.source_1.0.0.201506301446.jar: org/eclipse/incquery/uml/derivedfeatures/ConnectableElementEndMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.ConnectableElementEndQuerySpecification;
import org.eclipse.uml2.uml.ConnectableElement;
import org.eclipse.uml2.uml.ConnectorEnd;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.connectableElementEnd pattern,
 * to be used in conjunction with {@link ConnectableElementEndMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see ConnectableElementEndMatcher
 * @see ConnectableElementEndProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class ConnectableElementEndMatch extends BasePatternMatch {
  private ConnectableElement fSelf;
  
  private ConnectorEnd fTemp1;
  
  private static List<String> parameterNames = makeImmutableList("self", "temp1");
  
  private ConnectableElementEndMatch(final ConnectableElement pSelf, final ConnectorEnd pTemp1) {
    this.fSelf = pSelf;
    this.fTemp1 = pTemp1;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("self".equals(parameterName)) return this.fSelf;
    if ("temp1".equals(parameterName)) return this.fTemp1;
    return null;
  }
  
  public ConnectableElement getSelf() {
    return this.fSelf;
  }
  
  public ConnectorEnd getTemp1() {
    return this.fTemp1;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("self".equals(parameterName) ) {
    	this.fSelf = (org.eclipse.uml2.uml.ConnectableElement) newValue;
    	return true;
    }
    if ("temp1".equals(parameterName) ) {
    	this.fTemp1 = (org.eclipse.uml2.uml.ConnectorEnd) newValue;
    	return true;
    }
    return false;
  }
  
  public void setSelf(final ConnectableElement pSelf) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fSelf = pSelf;
  }
  
  public void setTemp1(final ConnectorEnd pTemp1) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fTemp1 = pTemp1;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.connectableElementEnd";
  }
  
  @Override
  public List<String> parameterNames() {
    return ConnectableElementEndMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fSelf, fTemp1};
  }
  
  @Override
  public ConnectableElementEndMatch toImmutable() {
    return isMutable() ? newMatch(fSelf, fTemp1) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"self\"=" + prettyPrintValue(fSelf) + ", ");
    
    result.append("\"temp1\"=" + prettyPrintValue(fTemp1)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fSelf == null) ? 0 : fSelf.hashCode());
    result = prime * result + ((fTemp1 == null) ? 0 : fTemp1.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof ConnectableElementEndMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    ConnectableElementEndMatch other = (ConnectableElementEndMatch) obj;
    if (fSelf == null) {if (other.fSelf != null) return false;}
    else if (!fSelf.equals(other.fSelf)) return false;
    if (fTemp1 == null) {if (other.fTemp1 != null) return false;}
    else if (!fTemp1.equals(other.fTemp1)) return false;
    return true;
  }
  
  @Override
  public ConnectableElementEndQuerySpecification specification() {
    try {
    	return ConnectableElementEndQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static ConnectableElementEndMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pTemp1 the fixed value of pattern parameter temp1, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static ConnectableElementEndMatch newMutableMatch(final ConnectableElement pSelf, final ConnectorEnd pTemp1) {
    return new Mutable(pSelf, pTemp1);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pTemp1 the fixed value of pattern parameter temp1, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static ConnectableElementEndMatch newMatch(final ConnectableElement pSelf, final ConnectorEnd pTemp1) {
    return new Immutable(pSelf, pTemp1);
  }
  
  private static final class Mutable extends ConnectableElementEndMatch {
    Mutable(final ConnectableElement pSelf, final ConnectorEnd pTemp1) {
      super(pSelf, pTemp1);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends ConnectableElementEndMatch {
    Immutable(final ConnectableElement pSelf, final ConnectorEnd pTemp1) {
      super(pSelf, pTemp1);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}

==> org.eclipse.incquery.uml.source_1.2.0.201602080945.jar: org/eclipse/incquery/uml/derivedfeatures/ConnectableElementEndMatch.java <==
package org.eclipse.incquery.uml.derivedfeatures;

import java.util.Arrays;
import java.util.List;
import org.eclipse.incquery.runtime.api.IPatternMatch;
import org.eclipse.incquery.runtime.api.impl.BasePatternMatch;
import org.eclipse.incquery.runtime.exception.IncQueryException;
import org.eclipse.incquery.uml.derivedfeatures.util.ConnectableElementEndQuerySpecification;
import org.eclipse.uml2.uml.ConnectableElement;
import org.eclipse.uml2.uml.ConnectorEnd;

/**
 * Pattern-specific match representation of the org.eclipse.incquery.uml.derivedfeatures.connectableElementEnd pattern,
 * to be used in conjunction with {@link ConnectableElementEndMatcher}.
 * 
 * <p>Class fields correspond to parameters of the pattern. Fields with value null are considered unassigned.
 * Each instance is a (possibly partial) substitution of pattern parameters,
 * usable to represent a match of the pattern in the result of a query,
 * or to specify the bound (fixed) input parameters when issuing a query.
 * 
 * @see ConnectableElementEndMatcher
 * @see ConnectableElementEndProcessor
 * 
 */
@SuppressWarnings("all")
public abstract class ConnectableElementEndMatch extends BasePatternMatch {
  private ConnectableElement fSelf;
  
  private ConnectorEnd fTemp1;
  
  private static List<String> parameterNames = makeImmutableList("self", "temp1");
  
  private ConnectableElementEndMatch(final ConnectableElement pSelf, final ConnectorEnd pTemp1) {
    this.fSelf = pSelf;
    this.fTemp1 = pTemp1;
  }
  
  @Override
  public Object get(final String parameterName) {
    if ("self".equals(parameterName)) return this.fSelf;
    if ("temp1".equals(parameterName)) return this.fTemp1;
    return null;
  }
  
  public ConnectableElement getSelf() {
    return this.fSelf;
  }
  
  public ConnectorEnd getTemp1() {
    return this.fTemp1;
  }
  
  @Override
  public boolean set(final String parameterName, final Object newValue) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    if ("self".equals(parameterName) ) {
    	this.fSelf = (ConnectableElement) newValue;
    	return true;
    }
    if ("temp1".equals(parameterName) ) {
    	this.fTemp1 = (ConnectorEnd) newValue;
    	return true;
    }
    return false;
  }
  
  public void setSelf(final ConnectableElement pSelf) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fSelf = pSelf;
  }
  
  public void setTemp1(final ConnectorEnd pTemp1) {
    if (!isMutable()) throw new java.lang.UnsupportedOperationException();
    this.fTemp1 = pTemp1;
  }
  
  @Override
  public String patternName() {
    return "org.eclipse.incquery.uml.derivedfeatures.connectableElementEnd";
  }
  
  @Override
  public List<String> parameterNames() {
    return ConnectableElementEndMatch.parameterNames;
  }
  
  @Override
  public Object[] toArray() {
    return new Object[]{fSelf, fTemp1};
  }
  
  @Override
  public ConnectableElementEndMatch toImmutable() {
    return isMutable() ? newMatch(fSelf, fTemp1) : this;
  }
  
  @Override
  public String prettyPrint() {
    StringBuilder result = new StringBuilder();
    result.append("\"self\"=" + prettyPrintValue(fSelf) + ", ");
    
    result.append("\"temp1\"=" + prettyPrintValue(fTemp1)
    );
    return result.toString();
  }
  
  @Override
  public int hashCode() {
    final int prime = 31;
    int result = 1;
    result = prime * result + ((fSelf == null) ? 0 : fSelf.hashCode());
    result = prime * result + ((fTemp1 == null) ? 0 : fTemp1.hashCode());
    return result;
  }
  
  @Override
  public boolean equals(final Object obj) {
    if (this == obj)
    	return true;
    if (!(obj instanceof ConnectableElementEndMatch)) { // this should be infrequent
    	if (obj == null) {
    		return false;
    	}
    	if (!(obj instanceof IPatternMatch)) {
    		return false;
    	}
    	IPatternMatch otherSig  = (IPatternMatch) obj;
    	if (!specification().equals(otherSig.specification()))
    		return false;
    	return Arrays.deepEquals(toArray(), otherSig.toArray());
    }
    ConnectableElementEndMatch other = (ConnectableElementEndMatch) obj;
    if (fSelf == null) {if (other.fSelf != null) return false;}
    else if (!fSelf.equals(other.fSelf)) return false;
    if (fTemp1 == null) {if (other.fTemp1 != null) return false;}
    else if (!fTemp1.equals(other.fTemp1)) return false;
    return true;
  }
  
  @Override
  public ConnectableElementEndQuerySpecification specification() {
    try {
    	return ConnectableElementEndQuerySpecification.instance();
    } catch (IncQueryException ex) {
     	// This cannot happen, as the match object can only be instantiated if the query specification exists
     	throw new IllegalStateException (ex);
    }
  }
  
  /**
   * Returns an empty, mutable match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @return the empty match.
   * 
   */
  public static ConnectableElementEndMatch newEmptyMatch() {
    return new Mutable(null, null);
  }
  
  /**
   * Returns a mutable (partial) match.
   * Fields of the mutable match can be filled to create a partial match, usable as matcher input.
   * 
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pTemp1 the fixed value of pattern parameter temp1, or null if not bound.
   * @return the new, mutable (partial) match object.
   * 
   */
  public static ConnectableElementEndMatch newMutableMatch(final ConnectableElement pSelf, final ConnectorEnd pTemp1) {
    return new Mutable(pSelf, pTemp1);
  }
  
  /**
   * Returns a new (partial) match.
   * This can be used e.g. to call the matcher with a partial match.
   * <p>The returned match will be immutable. Use {@link #newEmptyMatch()} to obtain a mutable match object.
   * @param pSelf the fixed value of pattern parameter self, or null if not bound.
   * @param pTemp1 the fixed value of pattern parameter temp1, or null if not bound.
   * @return the (partial) match object.
   * 
   */
  public static ConnectableElementEndMatch newMatch(final ConnectableElement pSelf, final ConnectorEnd pTemp1) {
    return new Immutable(pSelf, pTemp1);
  }
  
  private static final class Mutable extends ConnectableElementEndMatch {
    Mutable(final ConnectableElement pSelf, final ConnectorEnd pTemp1) {
      super(pSelf, pTemp1);
    }
    
    @Override
    public boolean isMutable() {
      return true;
    }
  }
  
  private static final class Immutable extends ConnectableElementEndMatch {
    Immutable(final ConnectableElement pSelf, final ConnectorEnd pTemp1) {
      super(pSelf, pTemp1);
    }
    
    @Override
    public boolean isMutable() {
      return false;
    }
  }
}
